pub struct ConnectInfo<R> { /* private fields */ }
Connection request information.

May contain known/pre-resolved socket address(es) or a host that needs resolving with DNS.

Implementations

Constructs new connection info using a request.

Constructs new connection info from request and known socket address.

Since socket address is known, Connector will skip the DNS resolution step.

Set connection port.

If request provided a port, this will override it.

Set connection socket address.

Set list of addresses.

Set local address to connection with.

Useful in situations where the IP address bound to a particular network interface is known. This would make sure the socket is opened through that interface.

Returns a reference to the connection request.

Returns request hostname.

Returns request port.

Get borrowed iterator of resolved request addresses.

Examples
let addr = SocketAddr::from(([127, 0, 0, 1], 4242));

let conn = ConnectInfo::new("localhost");
let mut addrs = conn.addrs();
assert!(addrs.next().is_none());

let conn = ConnectInfo::with_addr("localhost", addr);
let mut addrs = conn.addrs();
assert_eq!(addrs.next().unwrap(), addr);

Take owned iterator resolved request addresses.

Examples
let addr = SocketAddr::from(([127, 0, 0, 1], 4242));

let mut conn = ConnectInfo::new("localhost");
let mut addrs = conn.take_addrs();
assert!(addrs.next().is_none());

let mut conn = ConnectInfo::with_addr("localhost", addr);
let mut addrs = conn.take_addrs();
assert_eq!(addrs.next().unwrap(), addr);